| debug_contr_error | R Documentation |
Debug contrast errors in ANOVA-like models
debug_contr_error(dat, subset_vec = NULL)
dat |
A data frame of predictors. |
subset_vec |
Optional logical or numeric index vector used to subset rows before checks. |
A list with two elements:
Integer vector giving the number of levels for each factor
variable in dat.
List of factor level labels for each factor variable in
dat.
dat <- data.frame(
group = factor(rep(letters[1:3], each = 3)),
score = rnorm(9)
)
debug_contr_error(dat = dat)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.