| checkAssumptionsForAnova | R Documentation |
Check the assumptions for an ANOVA with a variable number of factors: Normality and Homogeneity of variance assumption.
checkAssumptionsForAnova(data, y, factors)
data |
the data frame |
y |
The dependent variable for which assumptions should be checked |
factors |
A character vector of factor names |
A message indicating whether to use parametric or non-parametric ANOVA
set.seed(123)
main_df <- data.frame(
tlx_mental = rnorm(40),
Video = factor(rep(c("A", "B"), each = 20)),
DriverPosition = factor(rep(c("Left", "Right"), times = 20))
)
checkAssumptionsForAnova(
data = main_df,
y = "tlx_mental",
factors = c("Video", "DriverPosition")
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.