# \donttest{
if (requireNamespace("report", quietly = TRUE)) {
# Simple linear model on the iris dataset
model <- stats::lm(
Sepal.Length ~ Sepal.Width + Petal.Length,
data = datasets::iris
)
# Format the report output, showing only significant items, removing the
# standard note, and wrapping bullet items in an itemize environment.
latexify_report(
report::report(model),
only_sig = TRUE,
remove_std = TRUE,
itemize = TRUE
)
}
# }
Run the code above in your browser using DataLab