| normalize | R Documentation |
This function normalizes the values in a vector to the range [new_min, new_max] based on their original range [old_min, old_max].
normalize(x_vector, old_min, old_max, new_min, new_max)
x_vector |
A numeric vector that you want to normalize. |
old_min |
The minimum value in the original scale of the data. |
old_max |
The maximum value in the original scale of the data. |
new_min |
The minimum value in the new scale to which you want to normalize the data. |
new_max |
The maximum value in the new scale to which you want to normalize the data. |
A numeric vector with the normalized values.
normalize(c(1, 2, 3, 4, 5), 1, 5, 0, 1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.