| reportART | R Documentation |
To easily copy and paste the results to your manuscript, the following commands must be defined in Latex:
\newcommand{\F}[3]{$F({#1},{#2})={#3}$}
\newcommand{\p}{\textit{p=}}
\newcommand{\pminor}{\textit{p$<$}}
reportART(model, dv = "Testdependentvariable", write_to_clipboard = FALSE)
model |
the model of the art |
dv |
the name of the dependent variable that should be reported |
write_to_clipboard |
whether to write to the clipboard |
A message describing the statistical results.
if (requireNamespace("ARTool", quietly = TRUE)) {
set.seed(123)
main_df <- data.frame(
tlx_mental = stats::rnorm(80),
Video = factor(rep(c("A", "B"), each = 40)),
gesture = factor(rep(c("G1", "G2"), times = 40)),
eHMI = factor(rep(c("On", "Off"), times = 40)),
UserID = factor(rep(1:20, each = 4))
)
art_model <- ARTool::art(
tlx_mental ~ Video * gesture * eHMI +
Error(UserID / (gesture * eHMI)),
data = main_df
)
model_anova <- stats::anova(art_model)
reportART(model_anova, dv = "mental demand")
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.