| reportMeanAndSD | R Documentation |
#' To easily copy and paste the results to your manuscript, the following commands must be defined in Latex:
\newcommand{\m}{\textit{M=}}
\newcommand{\sd}{\textit{SD=}}
reportMeanAndSD(data, iv = "testiv", dv = "testdv")
data |
the data frame |
iv |
the independent variable |
dv |
the dependent variable |
Mean and SD values
example_data <- data.frame(Condition = rep(c("A", "B", "C"),
each = 10), TLX1 = stats::rnorm(30))
reportMeanAndSD(example_data, iv = "Condition", dv = "TLX1")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.