reportMeanAndSD: Report the mean and standard deviation of a dependent variable for all levels of an independent variable rounded to the 2nd digit.
Description
#' To easily copy and paste the results to your manuscript, the following commands must be defined in Latex:
\newcommand{\m}{\textit{M=}}\newcommand{\sd}{\textit{SD=}}
Usage
reportMeanAndSD(data, iv = "testiv", dv = "testdv")