reportNPAV: Generate the Latex-text based on the NPAV by Lüpsen (see...

View source: R/reporting.R

reportNPAVR Documentation

Generate the Latex-text based on the NPAV by Lüpsen (see https://www.uni-koeln.de/~luepsen/R/). Only significant main and interaction effects are reported. P-values are rounded for the third digit and partial eta squared values are provided when possible. Attention: the independent variables of the formula and the term specifying the participant must be factors (i.e., use as.factor()).

Description

Deprecated: reportNPAV() will be removed in colleyRstats 0.1.0. Use reportART() with ARTool instead.

Usage

reportNPAV(model, dv = "Testdependentvariable", write_to_clipboard = FALSE)

Arguments

model

the model of the np.anova

dv

the name of the dependent variable that should be reported

write_to_clipboard

whether to write to the clipboard

Details

To easily copy and paste the results to your manuscript, the following commands must be defined in Latex: \newcommand{\F}[3]{$F({#1},{#2})={#3}$} \newcommand{\p}{\textit{p=}} \newcommand{\pminor}{\textit{p$<$}}

Value

A message describing the statistical results.

Examples

model <- data.frame(
  Df = c(1, 1, 10),
  `F value` = c(6.12, 5.01, NA),
  `Pr(>F)` = c(0.033, 0.045, NA),
  check.names = FALSE
)
rownames(model) <- c("Video", "gesture:eHMI", "Residuals")
reportNPAV(model, dv = "mental workload")

colleyRstats documentation built on May 3, 2026, 5:07 p.m.