| reportNPAV | R Documentation |
Deprecated: reportNPAV() will be removed in colleyRstats 0.1.0.
Use reportART() with ARTool instead.
reportNPAV(model, dv = "Testdependentvariable", write_to_clipboard = FALSE)
model |
the model of the np.anova |
dv |
the name of the dependent variable that should be reported |
write_to_clipboard |
whether to write to the clipboard |
To easily copy and paste the results to your manuscript, the following commands must be defined in Latex:
\newcommand{\F}[3]{$F({#1},{#2})={#3}$}
\newcommand{\p}{\textit{p=}}
\newcommand{\pminor}{\textit{p$<$}}
A message describing the statistical results.
model <- data.frame(
Df = c(1, 1, 10),
`F value` = c(6.12, 5.01, NA),
`Pr(>F)` = c(0.033, 0.045, NA),
check.names = FALSE
)
rownames(model) <- c("Video", "gesture:eHMI", "Residuals")
reportNPAV(model, dv = "mental workload")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.