| reportNparLD | R Documentation |
nparLD (see https://CRAN.R-project.org/package=nparLD).#' Only significant main and interaction effects are reported. P-values are rounded for the third digit and relative treatment effects (RTE) are included when available. Attention: the independent variables of the formula and the term specifying the participant must be factors (i.e., use as.factor()).
reportNparLD(model, dv = "Testdependentvariable", write_to_clipboard = FALSE)
model |
the model |
dv |
the dependent variable |
write_to_clipboard |
whether to write to the clipboard |
#' To easily copy and paste the results to your manuscript, the following commands must be defined in Latex:
\newcommand{\F}{\textit{F=}}
\newcommand{\p}{\textit{p=}}
\newcommand{\pminor}{\textit{p$<$}}
A message describing the statistical results.
if (requireNamespace("nparLD", quietly = TRUE)) {
# Small toy data set for nparLD
set.seed(123)
example_data <- data.frame(
Subject = factor(rep(1:10, each = 3)),
Time = factor(rep(c("T1", "T2", "T3"), times = 10)),
TLX1 = stats::rnorm(30, mean = 50, sd = 10)
)
# Fit nparLD model
model <- nparLD::nparLD(
TLX1 ~ Time,
data = example_data,
subject = "Subject",
description = FALSE
)
# Report the nparLD result
reportNparLD(model, dv = "TLX1")
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.