Flips a response scale so that a negatively worded item points the same way
as the rest of its subscale: min + max - x.
Examples
reverse_code(c(1, 3, 5, NA), min = 1, max = 5)
#> [1] 5 3 1 NA
Flips a response scale so that a negatively worded item points the same way
as the rest of its subscale: min + max - x.
reverse_code(c(1, 3, 5, NA), min = 1, max = 5)
#> [1] 5 3 1 NA